@@ -6,10 +6,6 @@ from bids.grabbids import BIDSLayout
 
 from rsHRF      import spm_dep, fourD_rsHRF
 
-#to decouple it from the docker version
-try: from .rsHRF_GUI import run 
-except: pass
-
 import warnings
 warnings.filterwarnings("ignore")
 
@@ -146,8 +142,9 @@ def run_rsHRF():
     if (args.GUI):
         if (nargs == 2):
             try:
+                from .rsHRF_GUI import run 
                 run.run()
-            except:
+            except ModuleNotFoundError:
                 parser.error('--GUI should not be used inside a Docker container')
         else:
             parser.error('--no other arguments should be supplied with --GUI')
